#
# spec file for package python-django-braces
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-django-braces
Version:        1.17.0
Release:        2.1
Summary:        Reusable, generic mixins for Django
License:        BSD-3-Clause
URL:            https://github.com/brack3t/django-braces/
Source:         https://files.pythonhosted.org/packages/source/d/django_braces/django_braces-%{version}.tar.gz
Patch1:         testhack.patch
BuildRequires:  %{python_module Django >= 2.2}
BuildRequires:  %{python_module factory_boy}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest-cov}
BuildRequires:  %{python_module pytest-django}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Django >= 2.2
BuildArch:      noarch
%python_subpackages

%description
Reusable, generic mixins for Django.

%prep
%setup -q -n django_braces-%{version}
%autopatch -p1
# do not mess with the test setup and rely on pytest defaults
rm conftest.py

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
export DJANGO_SETTINGS_MODULE=tests.settings
PYTHONPATH=.
# test_outdated_login gh#brack3t/django-braces#309
%pytest -k "not test_outdated_login"

%files %{python_files}
%doc README.md
%license LICENSE
%{python_sitelib}/braces
%{python_sitelib}/django_braces-%{version}*info

%changelog
* Tue Jun  3 2025 Steve Kowalik <steven.kowalik@suse.com>
- Switch to pyproject macros.
* Tue Apr 15 2025 Dirk Müller <dmueller@suse.com>
- update to 1.17.0:
  * MultiplePermissionsRequiredMixin didn't do
    object-level permission checks.
  * RecentLoginRequiredMixin no longer throws
    error about GET requests in Django >= 5.0
* Thu Nov  7 2024 Markéta Machová <mmachova@suse.com>
- Update to 1.16.0 (after 3 years!)
  * Fixed a few typos in the docs.
  * Removed unnecessarily explicit super() call
  * Use unittest.mock instead of mock package
  * Add support for Django 4.2
  * Updated the codebase to be more modern Python/Django
  * Cache-related headers
- Drop no-longer-needed modernize-braces.patch
- Skip test failing with Django 5.1
* Wed Apr 20 2022 Markéta Machová <mmachova@suse.com>
- do not require mock
* Thu Feb  3 2022 Steve Kowalik <steven.kowalik@suse.com>
- Update to 1.15.0:
  * Updates and fixes from #265
  * Typo fixes from #269 and #262
  * Dropped explicit support for Python versions before 3.7 and non-LTS
    versions of Django
- Dropped patch remove-py2-add-django3.patch:
  * Included
- Added patch modernize-braces.patch:
  * Add support for modern versions of Django
* Fri Mar 19 2021 Markéta Machová <mmachova@suse.com>
- Add upstream remove-py2-add-django3.patch to make the package
  compatible with Django 3.1 and testhack.patch to run tests
  on Django 3.1 (upstream sleeps)
* Tue Jan  7 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.14.0:
  * Tox now only tests recent Pythons and Djangos
  * Include necessary files to build docs in source tarball. Closes #250
  * Fixes deprecated imports, adds `six` as requirement
  * force text to prevent Python 2 unicode fun
- Remove merged patch dj21.patch
* Sun Mar 10 2019 Tomáš Chvátal <tchvatal@suse.com>
- Remove the url path for patch/source1 they differ and hopefully
  will be fixed in the future
* Sun Mar 10 2019 John Vandenberg <jayvdb@gmail.com>
- Activate test suite, adding form.html missing from sdist
- Add dj21.patch for Django 2.1 support
* Sun Feb 17 2019 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v1.13.0
